package geniusweb.party;

import java.util.Set;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * The capabilities of a party
 */
@JsonAutoDetect(fieldVisibility = Visibility.ANY, getterVisibility = Visibility.NONE, setterVisibility = Visibility.NONE)
public class Capabilities {
	/**
	 * List of supported protocols
	 */
	private final Set<String> behaviours;

	/**
	 * 
	 * @param protocols the protocols that a Party can handle
	 */
	@JsonCreator
	public Capabilities(@JsonProperty("behaviours") Set<String> behaviours) {
		if (behaviours == null) {
			throw new IllegalArgumentException("behaviours==null");
		}
		this.behaviours = behaviours;
	}

	public Set<String> getBehaviours() {
		return behaviours;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((behaviours == null) ? 0 : behaviours.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Capabilities other = (Capabilities) obj;
		if (behaviours == null) {
			if (other.behaviours != null)
				return false;
		} else if (!behaviours.equals(other.behaviours))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Capabilities[" + "Behaviours=" + behaviours + "]";
	}

}
